@@ -28,23 +28,61 @@ class Movie(KinopoiskObject):
     release = None
 
     posters = []
+    trailers = []
 
-    def __init__(self, **kwargs):
-        super(Movie, self).__init__(**kwargs)
-        from sources import MovieLink, MoviePremierLink, MovieMainPage, MoviePostersPage # import here for successful installing via pip
+    def __init__(self, *args, **kwargs):
+        super(Movie, self).__init__(*args, **kwargs)
+        from sources import MovieLink, MoviePremierLink, MovieMainPage, MoviePostersPage, MovieTrailersPage, MovieSeries # import here for successful installing via pip
         self.register_source('link', MovieLink)
         self.register_source('premier_link', MoviePremierLink)
         self.register_source('main_page', MovieMainPage)
         self.register_source('posters', MoviePostersPage)
+        self.register_source('trailers', MovieTrailersPage)
+        self.register_source('series', MovieSeries)
         self.posters = []
+        self.trailers = []
         self.audience = []
 
+        self.series = None
+        self.seasons = []
+
     def __repr__(self):
         return ('<%s (%s), %s>' % (self.title, self.title_original, self.year or '-')).encode('utf-8')
 
     def get_posters(self):
         return self.posters
 
+    def add_trailer(self, trailer_params):
+        trailer = Trailer(trailer_params)
+        if trailer.id not in [tr.id for tr in self.trailers]:
+            self.trailers += [trailer]
+
+class Trailer(object):
+    id = None
+    width = None
+    heigth = None
+    file = None
+    dom = 'tr'
+    advsys = "rutube"
+    sbt = ""
+    genres = None
+    preview_file = None
+    preview_width = None
+    preview_heigth = None
+
+    def __init__(self, params):
+        self.id = params['trailerId'].replace('top','')
+        self.width = params['trailerW']
+        self.heigth = params['trailerH']
+        self.file = params['trailerFile']
+        self.dom = params['trailerDom']
+        self.advsys = params['trailerAdvsys']
+        self.sbt = params['trailerSbt']
+        self.genres = params['genres']
+        self.preview_file = params['previewFile']
+        self.preview_width = params['previewW']
+        self.preview_heigth = params['previewH']
+
 class MovieManager(Manager):
     '''
     Movie manager
