@@ -28,7 +28,7 @@ class PersonMainPage(KinopoiskPage):
     '''
     Parser of main person page
     '''
-    url = '/level/4/people/%d/'
+    url = '/name/%d/'
 
     def parse(self, instance, content):
 
@@ -65,4 +65,4 @@ class PersonPhotosPage(KinopoiskImagesPage):
     Parser of person photos page
     '''
     url = '/name/%d/photos/'
-    field_name = 'photos'
+    field_name = 'photos'
\ No newline at end of file
